/*
 PINGUINO and MOD-RGB example
	
	This example uses a Pinguino board
	and the standard Pinguino I2C library
	to control the MOD-RGB module, which
	in turn controls the lights.
 
  This example has been tested with:
  - PIC32-PNGUINO(-OTG)
  - PIC32-PINGUINO-MICRO
  - PIC32-PINGUINO-MX220
	
	If you have any questions, email
	support@olimex.com
	
	OLIMEX, February 2013
	https://www.olimex.com
	
*/

/* Pinguino standard I2C library */
#include "i2c.c"

/* 
   Define the delay 
   Lower the number if you want the colors to change faster.
*/
#define SPEED 20

/* Device definition */
#define ADDRESS 0xA0  

void SetRGB(unsigned char R, unsigned char G, unsigned char B);   
    
void setup()
{
	I2C_init(I2C1, I2C_MASTER_MODE, I2C_SLEW_OFF);
}

void loop()
{
  unsigned char R, G, B; 
  int i;
  
  for(i = 0; i < 256; i++)
  {
     R = i;
     G = 0;
     B = 255; 
     SetRGB(R, G, B);
     delay(SPEED);
  }
  
  for(i = 0; i < 256; i++)
  {
     R = 255;
     G = 0;
     B = 255-i; 
     SetRGB(R, G, B);
     delay(SPEED);
  }
  
  for(i = 0; i < 256; i++)
  {
     R = 255;
     G = i;
     B = 0; 
     SetRGB(R, G, B);
     delay(SPEED);
  }
  
  for(i = 0; i < 256; i++)
  {
     R = 255-i;
     G = 255;
     B = 0; 
     SetRGB(R, G, B);   
     delay(SPEED);
  }
  
  for(i = 0; i < 256; i++)
  {
     R = 0;
     G = 255;
     B = i; 
     SetRGB(R, G, B);
     delay(SPEED);  
  }
  
  for(i = 0; i < 256; i++)
  {
     R = 0;
     G = 255-i;
     B = 255; 
     SetRGB(R, G, B); 
     delay(SPEED); 
  }
}

 void SetRGB(unsigned char R, unsigned char G, unsigned char B){
	I2C_start(I2C1);
	I2C_writechar(I2C1,0x48<<1);
	I2C_writechar(I2C1,0x05);
	I2C_writechar(I2C1,ADDRESS);
	I2C_writechar(I2C1,0x03);
	I2C_writechar(I2C1,R);
	I2C_writechar(I2C1,G);
	I2C_writechar(I2C1,B);
	I2C_stop(I2C1);	
 }   
